import { DocumentNode } from 'graphql';
/**
 * Extract Object types with @sourceFrom directives.
 *
 * Returns a map of type names to source package and function name tuples.
 */
export declare function extractSourceMapping(schema: DocumentNode): Record<string, [string, string]>;
/**
 * Extract fields types with @resolveBy directives.
 *
 * Returns a nested map of type names, field names, package and function name tuples.
 */
export declare function extractResolverMapping(schema: DocumentNode): Record<string, Record<string, [string, string]>>;
/**
 * Extract a list of all union types.
 */
export declare function extractUnions(schema: DocumentNode): string[];
/**
 * Extract a list of all interface types.
 */
export declare function extractInterfaces(schema: DocumentNode): string[];
/**
 * Dynamically retrieve a function from a package.
 */
export declare function executableDirective(module: string, fn: string): Promise<any>;
/**
 * Clean up a schema string and remove everything that could confuse Gatsby.
 */
export declare function cleanSchema(schema: DocumentNode): string;
